import pkg_resources
import sys

def load(entry_point_name, module_name):
    """ Scan the entry points and load extra settings. """
    entry_points = pkg_resources.iter_entry_points(entry_point_name)
    settings_module = sys.modules[module_name]
    for entry_point in entry_points:
        extra_module = entry_point.load()
        for key in dir(extra_module):
            if key.isupper():
                setattr(settings_module, key, getattr(extra_module, key))



#!/usr/bin/env python
from setuptools import setup

setup(
    name='django-extraconfig',
    version='0.1.1',
    description=('An entry-point based solution to extend'
                 'the Django configuration.'),
    long_description=open('README.rst').read(),
    keywords='Django settings',
    author='Sever Banesiu',
    author_email='banesiu.sever@gmail.com',
    url='http://github.com/pbs/django-extraconfig/',
    license='BSD',
    py_modules=['extraconfig'],
)
